# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fan.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='fan.proto',
  package='reachy.sdk.fan',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\tfan.proto\x12\x0ereachy.sdk.fan\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1bgoogle/protobuf/empty.proto\",\n\x05\x46\x61nId\x12\x0e\n\x04name\x18\x01 \x01(\tH\x00\x12\r\n\x03uid\x18\x02 \x01(\rH\x00\x42\x04\n\x02id\"%\n\x06\x46\x61nsId\x12\r\n\x05names\x18\x01 \x03(\t\x12\x0c\n\x04uids\x18\x02 \x03(\r\"e\n\x10\x46\x61nsStateRequest\x12\"\n\x03ids\x18\x01 \x03(\x0b\x32\x15.reachy.sdk.fan.FanId\x12-\n\ttimestamp\x18\x0f \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x16\n\x08\x46\x61nState\x12\n\n\x02on\x18\x01 \x01(\x08\"\x88\x01\n\tFansState\x12\"\n\x03ids\x18\x01 \x03(\x0b\x32\x15.reachy.sdk.fan.FanId\x12(\n\x06states\x18\x02 \x03(\x0b\x32\x18.reachy.sdk.fan.FanState\x12-\n\ttimestamp\x18\x0f \x01(\x0b\x32\x1a.google.protobuf.Timestamp\";\n\nFanCommand\x12!\n\x02id\x18\x01 \x01(\x0b\x32\x15.reachy.sdk.fan.FanId\x12\n\n\x02on\x18\x02 \x01(\x08\"j\n\x0b\x46\x61nsCommand\x12,\n\x08\x63ommands\x18\x01 \x03(\x0b\x32\x1a.reachy.sdk.fan.FanCommand\x12-\n\ttimestamp\x18\x0f \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"!\n\x0e\x46\x61nsCommandAck\x12\x0f\n\x07success\x18\x01 \x01(\x08\x32\xf4\x01\n\x14\x46\x61nControllerService\x12>\n\x0cGetAllFansId\x12\x16.google.protobuf.Empty\x1a\x16.reachy.sdk.fan.FansId\x12K\n\x0cGetFansState\x12 .reachy.sdk.fan.FansStateRequest\x1a\x19.reachy.sdk.fan.FansState\x12O\n\x10SendFansCommands\x12\x1b.reachy.sdk.fan.FansCommand\x1a\x1e.reachy.sdk.fan.FansCommandAckb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,])




_FANID = _descriptor.Descriptor(
  name='FanId',
  full_name='reachy.sdk.fan.FanId',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='reachy.sdk.fan.FanId.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uid', full_name='reachy.sdk.fan.FanId.uid', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='id', full_name='reachy.sdk.fan.FanId.id',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=91,
  serialized_end=135,
)


_FANSID = _descriptor.Descriptor(
  name='FansId',
  full_name='reachy.sdk.fan.FansId',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='names', full_name='reachy.sdk.fan.FansId.names', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uids', full_name='reachy.sdk.fan.FansId.uids', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=137,
  serialized_end=174,
)


_FANSSTATEREQUEST = _descriptor.Descriptor(
  name='FansStateRequest',
  full_name='reachy.sdk.fan.FansStateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ids', full_name='reachy.sdk.fan.FansStateRequest.ids', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='reachy.sdk.fan.FansStateRequest.timestamp', index=1,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=176,
  serialized_end=277,
)


_FANSTATE = _descriptor.Descriptor(
  name='FanState',
  full_name='reachy.sdk.fan.FanState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='on', full_name='reachy.sdk.fan.FanState.on', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=279,
  serialized_end=301,
)


_FANSSTATE = _descriptor.Descriptor(
  name='FansState',
  full_name='reachy.sdk.fan.FansState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ids', full_name='reachy.sdk.fan.FansState.ids', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='states', full_name='reachy.sdk.fan.FansState.states', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='reachy.sdk.fan.FansState.timestamp', index=2,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=304,
  serialized_end=440,
)


_FANCOMMAND = _descriptor.Descriptor(
  name='FanCommand',
  full_name='reachy.sdk.fan.FanCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='reachy.sdk.fan.FanCommand.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='on', full_name='reachy.sdk.fan.FanCommand.on', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=442,
  serialized_end=501,
)


_FANSCOMMAND = _descriptor.Descriptor(
  name='FansCommand',
  full_name='reachy.sdk.fan.FansCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='commands', full_name='reachy.sdk.fan.FansCommand.commands', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='reachy.sdk.fan.FansCommand.timestamp', index=1,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=503,
  serialized_end=609,
)


_FANSCOMMANDACK = _descriptor.Descriptor(
  name='FansCommandAck',
  full_name='reachy.sdk.fan.FansCommandAck',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='reachy.sdk.fan.FansCommandAck.success', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=611,
  serialized_end=644,
)

_FANID.oneofs_by_name['id'].fields.append(
  _FANID.fields_by_name['name'])
_FANID.fields_by_name['name'].containing_oneof = _FANID.oneofs_by_name['id']
_FANID.oneofs_by_name['id'].fields.append(
  _FANID.fields_by_name['uid'])
_FANID.fields_by_name['uid'].containing_oneof = _FANID.oneofs_by_name['id']
_FANSSTATEREQUEST.fields_by_name['ids'].message_type = _FANID
_FANSSTATEREQUEST.fields_by_name['timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_FANSSTATE.fields_by_name['ids'].message_type = _FANID
_FANSSTATE.fields_by_name['states'].message_type = _FANSTATE
_FANSSTATE.fields_by_name['timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_FANCOMMAND.fields_by_name['id'].message_type = _FANID
_FANSCOMMAND.fields_by_name['commands'].message_type = _FANCOMMAND
_FANSCOMMAND.fields_by_name['timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
DESCRIPTOR.message_types_by_name['FanId'] = _FANID
DESCRIPTOR.message_types_by_name['FansId'] = _FANSID
DESCRIPTOR.message_types_by_name['FansStateRequest'] = _FANSSTATEREQUEST
DESCRIPTOR.message_types_by_name['FanState'] = _FANSTATE
DESCRIPTOR.message_types_by_name['FansState'] = _FANSSTATE
DESCRIPTOR.message_types_by_name['FanCommand'] = _FANCOMMAND
DESCRIPTOR.message_types_by_name['FansCommand'] = _FANSCOMMAND
DESCRIPTOR.message_types_by_name['FansCommandAck'] = _FANSCOMMANDACK
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FanId = _reflection.GeneratedProtocolMessageType('FanId', (_message.Message,), {
  'DESCRIPTOR' : _FANID,
  '__module__' : 'fan_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.fan.FanId)
  })
_sym_db.RegisterMessage(FanId)

FansId = _reflection.GeneratedProtocolMessageType('FansId', (_message.Message,), {
  'DESCRIPTOR' : _FANSID,
  '__module__' : 'fan_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.fan.FansId)
  })
_sym_db.RegisterMessage(FansId)

FansStateRequest = _reflection.GeneratedProtocolMessageType('FansStateRequest', (_message.Message,), {
  'DESCRIPTOR' : _FANSSTATEREQUEST,
  '__module__' : 'fan_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.fan.FansStateRequest)
  })
_sym_db.RegisterMessage(FansStateRequest)

FanState = _reflection.GeneratedProtocolMessageType('FanState', (_message.Message,), {
  'DESCRIPTOR' : _FANSTATE,
  '__module__' : 'fan_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.fan.FanState)
  })
_sym_db.RegisterMessage(FanState)

FansState = _reflection.GeneratedProtocolMessageType('FansState', (_message.Message,), {
  'DESCRIPTOR' : _FANSSTATE,
  '__module__' : 'fan_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.fan.FansState)
  })
_sym_db.RegisterMessage(FansState)

FanCommand = _reflection.GeneratedProtocolMessageType('FanCommand', (_message.Message,), {
  'DESCRIPTOR' : _FANCOMMAND,
  '__module__' : 'fan_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.fan.FanCommand)
  })
_sym_db.RegisterMessage(FanCommand)

FansCommand = _reflection.GeneratedProtocolMessageType('FansCommand', (_message.Message,), {
  'DESCRIPTOR' : _FANSCOMMAND,
  '__module__' : 'fan_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.fan.FansCommand)
  })
_sym_db.RegisterMessage(FansCommand)

FansCommandAck = _reflection.GeneratedProtocolMessageType('FansCommandAck', (_message.Message,), {
  'DESCRIPTOR' : _FANSCOMMANDACK,
  '__module__' : 'fan_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.fan.FansCommandAck)
  })
_sym_db.RegisterMessage(FansCommandAck)



_FANCONTROLLERSERVICE = _descriptor.ServiceDescriptor(
  name='FanControllerService',
  full_name='reachy.sdk.fan.FanControllerService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=647,
  serialized_end=891,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetAllFansId',
    full_name='reachy.sdk.fan.FanControllerService.GetAllFansId',
    index=0,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_FANSID,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetFansState',
    full_name='reachy.sdk.fan.FanControllerService.GetFansState',
    index=1,
    containing_service=None,
    input_type=_FANSSTATEREQUEST,
    output_type=_FANSSTATE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SendFansCommands',
    full_name='reachy.sdk.fan.FanControllerService.SendFansCommands',
    index=2,
    containing_service=None,
    input_type=_FANSCOMMAND,
    output_type=_FANSCOMMANDACK,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_FANCONTROLLERSERVICE)

DESCRIPTOR.services_by_name['FanControllerService'] = _FANCONTROLLERSERVICE

# @@protoc_insertion_point(module_scope)
