# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: zoom_command.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='zoom_command.proto',
  package='reachy.sdk.zoom',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x12zoom_command.proto\x12\x0freachy.sdk.zoom\x1a\x1bgoogle/protobuf/empty.proto\"\x1a\n\tZoomSpeed\x12\r\n\x05speed\x18\x01 \x01(\r\",\n\x0bZoomCommand\x12\x0c\n\x04side\x18\x01 \x01(\t\x12\x0f\n\x07\x63ommand\x18\x02 \x01(\t\".\n\x05\x45mpty\x12%\n\x05\x65mpty\x18\x01 \x01(\x0b\x32\x16.google.protobuf.Empty2\xa4\x01\n\x15ZoomControllerService\x12\x42\n\x0cSetZoomSpeed\x12\x1a.reachy.sdk.zoom.ZoomSpeed\x1a\x16.reachy.sdk.zoom.Empty\x12G\n\x0fSendZoomCommand\x12\x1c.reachy.sdk.zoom.ZoomCommand\x1a\x16.reachy.sdk.zoom.Emptyb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,])




_ZOOMSPEED = _descriptor.Descriptor(
  name='ZoomSpeed',
  full_name='reachy.sdk.zoom.ZoomSpeed',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='speed', full_name='reachy.sdk.zoom.ZoomSpeed.speed', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=68,
  serialized_end=94,
)


_ZOOMCOMMAND = _descriptor.Descriptor(
  name='ZoomCommand',
  full_name='reachy.sdk.zoom.ZoomCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='side', full_name='reachy.sdk.zoom.ZoomCommand.side', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='command', full_name='reachy.sdk.zoom.ZoomCommand.command', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=96,
  serialized_end=140,
)


_EMPTY = _descriptor.Descriptor(
  name='Empty',
  full_name='reachy.sdk.zoom.Empty',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='empty', full_name='reachy.sdk.zoom.Empty.empty', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=142,
  serialized_end=188,
)

_EMPTY.fields_by_name['empty'].message_type = google_dot_protobuf_dot_empty__pb2._EMPTY
DESCRIPTOR.message_types_by_name['ZoomSpeed'] = _ZOOMSPEED
DESCRIPTOR.message_types_by_name['ZoomCommand'] = _ZOOMCOMMAND
DESCRIPTOR.message_types_by_name['Empty'] = _EMPTY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ZoomSpeed = _reflection.GeneratedProtocolMessageType('ZoomSpeed', (_message.Message,), {
  'DESCRIPTOR' : _ZOOMSPEED,
  '__module__' : 'zoom_command_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.zoom.ZoomSpeed)
  })
_sym_db.RegisterMessage(ZoomSpeed)

ZoomCommand = _reflection.GeneratedProtocolMessageType('ZoomCommand', (_message.Message,), {
  'DESCRIPTOR' : _ZOOMCOMMAND,
  '__module__' : 'zoom_command_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.zoom.ZoomCommand)
  })
_sym_db.RegisterMessage(ZoomCommand)

Empty = _reflection.GeneratedProtocolMessageType('Empty', (_message.Message,), {
  'DESCRIPTOR' : _EMPTY,
  '__module__' : 'zoom_command_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.zoom.Empty)
  })
_sym_db.RegisterMessage(Empty)



_ZOOMCONTROLLERSERVICE = _descriptor.ServiceDescriptor(
  name='ZoomControllerService',
  full_name='reachy.sdk.zoom.ZoomControllerService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=191,
  serialized_end=355,
  methods=[
  _descriptor.MethodDescriptor(
    name='SetZoomSpeed',
    full_name='reachy.sdk.zoom.ZoomControllerService.SetZoomSpeed',
    index=0,
    containing_service=None,
    input_type=_ZOOMSPEED,
    output_type=_EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SendZoomCommand',
    full_name='reachy.sdk.zoom.ZoomControllerService.SendZoomCommand',
    index=1,
    containing_service=None,
    input_type=_ZOOMCOMMAND,
    output_type=_EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_ZOOMCONTROLLERSERVICE)

DESCRIPTOR.services_by_name['ZoomControllerService'] = _ZOOMCONTROLLERSERVICE

# @@protoc_insertion_point(module_scope)
