# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sensor.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='sensor.proto',
  package='reachy.sdk.joint',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x0csensor.proto\x12\x10reachy.sdk.joint\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1bgoogle/protobuf/empty.proto\"/\n\x08SensorId\x12\x0e\n\x04name\x18\x01 \x01(\tH\x00\x12\r\n\x03uid\x18\x02 \x01(\rH\x00\x42\x04\n\x02id\"(\n\tSensorsId\x12\r\n\x05names\x18\x01 \x03(\t\x12\x0c\n\x04uids\x18\x02 \x03(\r\"!\n\x10\x46orceSensorState\x12\r\n\x05\x66orce\x18\x01 \x01(\x02\"X\n\x0bSensorState\x12@\n\x12\x66orce_sensor_state\x18\x01 \x01(\x0b\x32\".reachy.sdk.joint.ForceSensorStateH\x00\x42\x07\n\x05state\"\x95\x01\n\x0cSensorsState\x12\'\n\x03ids\x18\x01 \x03(\x0b\x32\x1a.reachy.sdk.joint.SensorId\x12-\n\x06states\x18\x02 \x03(\x0b\x32\x1d.reachy.sdk.joint.SensorState\x12-\n\ttimestamp\x18\x0f \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"m\n\x13SensorsStateRequest\x12\'\n\x03ids\x18\x01 \x03(\x0b\x32\x1a.reachy.sdk.joint.SensorId\x12-\n\ttimestamp\x18\x0f \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"n\n\x19StreamSensorsStateRequest\x12\x36\n\x07request\x18\x01 \x01(\x0b\x32%.reachy.sdk.joint.SensorsStateRequest\x12\x19\n\x11publish_frequency\x18\x02 \x01(\x02\x32\x9b\x02\n\rSensorService\x12K\n\x14GetAllForceSensorsId\x12\x16.google.protobuf.Empty\x1a\x1b.reachy.sdk.joint.SensorsId\x12X\n\x0fGetSensorsState\x12%.reachy.sdk.joint.SensorsStateRequest\x1a\x1e.reachy.sdk.joint.SensorsState\x12\x63\n\x12StreamSensorStates\x12+.reachy.sdk.joint.StreamSensorsStateRequest\x1a\x1e.reachy.sdk.joint.SensorsState0\x01\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,])




_SENSORID = _descriptor.Descriptor(
  name='SensorId',
  full_name='reachy.sdk.joint.SensorId',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='reachy.sdk.joint.SensorId.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uid', full_name='reachy.sdk.joint.SensorId.uid', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='id', full_name='reachy.sdk.joint.SensorId.id',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=96,
  serialized_end=143,
)


_SENSORSID = _descriptor.Descriptor(
  name='SensorsId',
  full_name='reachy.sdk.joint.SensorsId',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='names', full_name='reachy.sdk.joint.SensorsId.names', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uids', full_name='reachy.sdk.joint.SensorsId.uids', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=145,
  serialized_end=185,
)


_FORCESENSORSTATE = _descriptor.Descriptor(
  name='ForceSensorState',
  full_name='reachy.sdk.joint.ForceSensorState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='force', full_name='reachy.sdk.joint.ForceSensorState.force', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=187,
  serialized_end=220,
)


_SENSORSTATE = _descriptor.Descriptor(
  name='SensorState',
  full_name='reachy.sdk.joint.SensorState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='force_sensor_state', full_name='reachy.sdk.joint.SensorState.force_sensor_state', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='state', full_name='reachy.sdk.joint.SensorState.state',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=222,
  serialized_end=310,
)


_SENSORSSTATE = _descriptor.Descriptor(
  name='SensorsState',
  full_name='reachy.sdk.joint.SensorsState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ids', full_name='reachy.sdk.joint.SensorsState.ids', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='states', full_name='reachy.sdk.joint.SensorsState.states', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='reachy.sdk.joint.SensorsState.timestamp', index=2,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=313,
  serialized_end=462,
)


_SENSORSSTATEREQUEST = _descriptor.Descriptor(
  name='SensorsStateRequest',
  full_name='reachy.sdk.joint.SensorsStateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ids', full_name='reachy.sdk.joint.SensorsStateRequest.ids', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='reachy.sdk.joint.SensorsStateRequest.timestamp', index=1,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=464,
  serialized_end=573,
)


_STREAMSENSORSSTATEREQUEST = _descriptor.Descriptor(
  name='StreamSensorsStateRequest',
  full_name='reachy.sdk.joint.StreamSensorsStateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='reachy.sdk.joint.StreamSensorsStateRequest.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='publish_frequency', full_name='reachy.sdk.joint.StreamSensorsStateRequest.publish_frequency', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=575,
  serialized_end=685,
)

_SENSORID.oneofs_by_name['id'].fields.append(
  _SENSORID.fields_by_name['name'])
_SENSORID.fields_by_name['name'].containing_oneof = _SENSORID.oneofs_by_name['id']
_SENSORID.oneofs_by_name['id'].fields.append(
  _SENSORID.fields_by_name['uid'])
_SENSORID.fields_by_name['uid'].containing_oneof = _SENSORID.oneofs_by_name['id']
_SENSORSTATE.fields_by_name['force_sensor_state'].message_type = _FORCESENSORSTATE
_SENSORSTATE.oneofs_by_name['state'].fields.append(
  _SENSORSTATE.fields_by_name['force_sensor_state'])
_SENSORSTATE.fields_by_name['force_sensor_state'].containing_oneof = _SENSORSTATE.oneofs_by_name['state']
_SENSORSSTATE.fields_by_name['ids'].message_type = _SENSORID
_SENSORSSTATE.fields_by_name['states'].message_type = _SENSORSTATE
_SENSORSSTATE.fields_by_name['timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SENSORSSTATEREQUEST.fields_by_name['ids'].message_type = _SENSORID
_SENSORSSTATEREQUEST.fields_by_name['timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_STREAMSENSORSSTATEREQUEST.fields_by_name['request'].message_type = _SENSORSSTATEREQUEST
DESCRIPTOR.message_types_by_name['SensorId'] = _SENSORID
DESCRIPTOR.message_types_by_name['SensorsId'] = _SENSORSID
DESCRIPTOR.message_types_by_name['ForceSensorState'] = _FORCESENSORSTATE
DESCRIPTOR.message_types_by_name['SensorState'] = _SENSORSTATE
DESCRIPTOR.message_types_by_name['SensorsState'] = _SENSORSSTATE
DESCRIPTOR.message_types_by_name['SensorsStateRequest'] = _SENSORSSTATEREQUEST
DESCRIPTOR.message_types_by_name['StreamSensorsStateRequest'] = _STREAMSENSORSSTATEREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SensorId = _reflection.GeneratedProtocolMessageType('SensorId', (_message.Message,), {
  'DESCRIPTOR' : _SENSORID,
  '__module__' : 'sensor_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.joint.SensorId)
  })
_sym_db.RegisterMessage(SensorId)

SensorsId = _reflection.GeneratedProtocolMessageType('SensorsId', (_message.Message,), {
  'DESCRIPTOR' : _SENSORSID,
  '__module__' : 'sensor_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.joint.SensorsId)
  })
_sym_db.RegisterMessage(SensorsId)

ForceSensorState = _reflection.GeneratedProtocolMessageType('ForceSensorState', (_message.Message,), {
  'DESCRIPTOR' : _FORCESENSORSTATE,
  '__module__' : 'sensor_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.joint.ForceSensorState)
  })
_sym_db.RegisterMessage(ForceSensorState)

SensorState = _reflection.GeneratedProtocolMessageType('SensorState', (_message.Message,), {
  'DESCRIPTOR' : _SENSORSTATE,
  '__module__' : 'sensor_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.joint.SensorState)
  })
_sym_db.RegisterMessage(SensorState)

SensorsState = _reflection.GeneratedProtocolMessageType('SensorsState', (_message.Message,), {
  'DESCRIPTOR' : _SENSORSSTATE,
  '__module__' : 'sensor_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.joint.SensorsState)
  })
_sym_db.RegisterMessage(SensorsState)

SensorsStateRequest = _reflection.GeneratedProtocolMessageType('SensorsStateRequest', (_message.Message,), {
  'DESCRIPTOR' : _SENSORSSTATEREQUEST,
  '__module__' : 'sensor_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.joint.SensorsStateRequest)
  })
_sym_db.RegisterMessage(SensorsStateRequest)

StreamSensorsStateRequest = _reflection.GeneratedProtocolMessageType('StreamSensorsStateRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMSENSORSSTATEREQUEST,
  '__module__' : 'sensor_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.joint.StreamSensorsStateRequest)
  })
_sym_db.RegisterMessage(StreamSensorsStateRequest)



_SENSORSERVICE = _descriptor.ServiceDescriptor(
  name='SensorService',
  full_name='reachy.sdk.joint.SensorService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=688,
  serialized_end=971,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetAllForceSensorsId',
    full_name='reachy.sdk.joint.SensorService.GetAllForceSensorsId',
    index=0,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_SENSORSID,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetSensorsState',
    full_name='reachy.sdk.joint.SensorService.GetSensorsState',
    index=1,
    containing_service=None,
    input_type=_SENSORSSTATEREQUEST,
    output_type=_SENSORSSTATE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StreamSensorStates',
    full_name='reachy.sdk.joint.SensorService.StreamSensorStates',
    index=2,
    containing_service=None,
    input_type=_STREAMSENSORSSTATEREQUEST,
    output_type=_SENSORSSTATE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_SENSORSERVICE)

DESCRIPTOR.services_by_name['SensorService'] = _SENSORSERVICE

# @@protoc_insertion_point(module_scope)
